# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_volatility.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/intraday_analytics/v1/intraday_volatility.proto',
  package='systemathics.apis.services.intraday_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nJsystemathics/apis/services/intraday_analytics/v1/intraday_volatility.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xf3\x01\n\x19IntradayVolatilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"+\n\x1aIntradayVolatilityResponse\x12\r\n\x05value\x18\x01 \x01(\x01\x32\xcd\x01\n\x19IntradayVolatilityService\x12\xaf\x01\n\x12IntradayVolatility\x12K.systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest\x1aL.systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponseb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2.DESCRIPTOR,])




_INTRADAYVOLATILITYREQUEST = _descriptor.Descriptor(
  name='IntradayVolatilityRequest',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest.sampling', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest.adjustment', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=524,
)


_INTRADAYVOLATILITYRESPONSE = _descriptor.Descriptor(
  name='IntradayVolatilityResponse',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponse.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=569,
)

_INTRADAYVOLATILITYREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_INTRADAYVOLATILITYREQUEST.fields_by_name['sampling'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2._SAMPLING
_INTRADAYVOLATILITYREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
DESCRIPTOR.message_types_by_name['IntradayVolatilityRequest'] = _INTRADAYVOLATILITYREQUEST
DESCRIPTOR.message_types_by_name['IntradayVolatilityResponse'] = _INTRADAYVOLATILITYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IntradayVolatilityRequest = _reflection.GeneratedProtocolMessageType('IntradayVolatilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVOLATILITYREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityRequest)
  })
_sym_db.RegisterMessage(IntradayVolatilityRequest)

IntradayVolatilityResponse = _reflection.GeneratedProtocolMessageType('IntradayVolatilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYVOLATILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_volatility_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityResponse)
  })
_sym_db.RegisterMessage(IntradayVolatilityResponse)



_INTRADAYVOLATILITYSERVICE = _descriptor.ServiceDescriptor(
  name='IntradayVolatilityService',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=572,
  serialized_end=777,
  methods=[
  _descriptor.MethodDescriptor(
    name='IntradayVolatility',
    full_name='systemathics.apis.services.intraday_analytics.v1.IntradayVolatilityService.IntradayVolatility',
    index=0,
    containing_service=None,
    input_type=_INTRADAYVOLATILITYREQUEST,
    output_type=_INTRADAYVOLATILITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INTRADAYVOLATILITYSERVICE)

DESCRIPTOR.services_by_name['IntradayVolatilityService'] = _INTRADAYVOLATILITYSERVICE

# @@protoc_insertion_point(module_scope)
