# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_macd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/intraday_analytics/v1/intraday_macd.proto',
  package='systemathics.apis.services.intraday_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nDsystemathics/apis/services/intraday_analytics/v1/intraday_macd.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\x8a\x02\n\x13IntradayMacdRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0c\n\x04long\x18\x04 \x01(\x05\x12\r\n\x05short\x18\x05 \x01(\x05\x12\x12\n\nadjustment\x18\x06 \x01(\x08\"h\n\x14IntradayMacdResponse\x12P\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x42.systemathics.apis.services.intraday_analytics.v1.IntradayMacdData\"|\n\x10IntradayMacdData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0c\n\x04macd\x18\x03 \x01(\x01\x12\r\n\x05short\x18\x04 \x01(\x01\x12\x0c\n\x04long\x18\x05 \x01(\x01\x32\xb5\x01\n\x13IntradayMacdService\x12\x9d\x01\n\x0cIntradayMacd\x12\x45.systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest\x1a\x46.systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2.DESCRIPTOR,])




_INTRADAYMACDREQUEST = _descriptor.Descriptor(
  name='IntradayMacdRequest',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.sampling', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.constraints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.long', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.short', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest.adjustment', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=308,
  serialized_end=574,
)


_INTRADAYMACDRESPONSE = _descriptor.Descriptor(
  name='IntradayMacdResponse',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=680,
)


_INTRADAYMACDDATA = _descriptor.Descriptor(
  name='IntradayMacdData',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData.time_stamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='macd', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData.macd', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData.short', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long', full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdData.long', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=806,
)

_INTRADAYMACDREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_INTRADAYMACDREQUEST.fields_by_name['sampling'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2._SAMPLING
_INTRADAYMACDREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_INTRADAYMACDRESPONSE.fields_by_name['data'].message_type = _INTRADAYMACDDATA
_INTRADAYMACDDATA.fields_by_name['time_stamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['IntradayMacdRequest'] = _INTRADAYMACDREQUEST
DESCRIPTOR.message_types_by_name['IntradayMacdResponse'] = _INTRADAYMACDRESPONSE
DESCRIPTOR.message_types_by_name['IntradayMacdData'] = _INTRADAYMACDDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IntradayMacdRequest = _reflection.GeneratedProtocolMessageType('IntradayMacdRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest)
  })
_sym_db.RegisterMessage(IntradayMacdRequest)

IntradayMacdResponse = _reflection.GeneratedProtocolMessageType('IntradayMacdResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponse)
  })
_sym_db.RegisterMessage(IntradayMacdResponse)

IntradayMacdData = _reflection.GeneratedProtocolMessageType('IntradayMacdData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYMACDDATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayMacdData)
  })
_sym_db.RegisterMessage(IntradayMacdData)



_INTRADAYMACDSERVICE = _descriptor.ServiceDescriptor(
  name='IntradayMacdService',
  full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=809,
  serialized_end=990,
  methods=[
  _descriptor.MethodDescriptor(
    name='IntradayMacd',
    full_name='systemathics.apis.services.intraday_analytics.v1.IntradayMacdService.IntradayMacd',
    index=0,
    containing_service=None,
    input_type=_INTRADAYMACDREQUEST,
    output_type=_INTRADAYMACDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INTRADAYMACDSERVICE)

DESCRIPTOR.services_by_name['IntradayMacdService'] = _INTRADAYMACDSERVICE

# @@protoc_insertion_point(module_scope)
