# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/sustainability/v1/sustainability.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/sustainability/v1/sustainability.proto',
  package='systemathics.apis.services.sustainability.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAsystemathics/apis/services/sustainability/v1/sustainability.proto\x12,systemathics.apis.services.sustainability.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"Y\n\x15SustainabilityRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\"d\n\x16SustainabilityResponse\x12J\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.sustainability.v1.Sustainability\"\x8a\x01\n\x0eSustainability\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\x12\x0b\n\x03min\x18\x06 \x01(\x01\x12\x0b\n\x03max\x18\x07 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t2\xb5\x01\n\x15SustainabilityService\x12\x9b\x01\n\x0eSustainability\x12\x43.systemathics.apis.services.sustainability.v1.SustainabilityRequest\x1a\x44.systemathics.apis.services.sustainability.v1.SustainabilityResponseb\x06proto3'
  ,
  dependencies=[systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])




_SUSTAINABILITYREQUEST = _descriptor.Descriptor(
  name='SustainabilityRequest',
  full_name='systemathics.apis.services.sustainability.v1.SustainabilityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.sustainability.v1.SustainabilityRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=255,
)


_SUSTAINABILITYRESPONSE = _descriptor.Descriptor(
  name='SustainabilityResponse',
  full_name='systemathics.apis.services.sustainability.v1.SustainabilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.sustainability.v1.SustainabilityResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=257,
  serialized_end=357,
)


_SUSTAINABILITY = _descriptor.Descriptor(
  name='Sustainability',
  full_name='systemathics.apis.services.sustainability.v1.Sustainability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider', full_name='systemathics.apis.services.sustainability.v1.Sustainability.provider', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.sustainability.v1.Sustainability.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='systemathics.apis.services.sustainability.v1.Sustainability.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='systemathics.apis.services.sustainability.v1.Sustainability.parent', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.sustainability.v1.Sustainability.value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='systemathics.apis.services.sustainability.v1.Sustainability.min', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='systemathics.apis.services.sustainability.v1.Sustainability.max', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='systemathics.apis.services.sustainability.v1.Sustainability.description', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=498,
)

_SUSTAINABILITYREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_SUSTAINABILITYRESPONSE.fields_by_name['data'].message_type = _SUSTAINABILITY
DESCRIPTOR.message_types_by_name['SustainabilityRequest'] = _SUSTAINABILITYREQUEST
DESCRIPTOR.message_types_by_name['SustainabilityResponse'] = _SUSTAINABILITYRESPONSE
DESCRIPTOR.message_types_by_name['Sustainability'] = _SUSTAINABILITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SustainabilityRequest = _reflection.GeneratedProtocolMessageType('SustainabilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITYREQUEST,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.SustainabilityRequest)
  })
_sym_db.RegisterMessage(SustainabilityRequest)

SustainabilityResponse = _reflection.GeneratedProtocolMessageType('SustainabilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITYRESPONSE,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.SustainabilityResponse)
  })
_sym_db.RegisterMessage(SustainabilityResponse)

Sustainability = _reflection.GeneratedProtocolMessageType('Sustainability', (_message.Message,), {
  'DESCRIPTOR' : _SUSTAINABILITY,
  '__module__' : 'systemathics.apis.services.sustainability.v1.sustainability_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.sustainability.v1.Sustainability)
  })
_sym_db.RegisterMessage(Sustainability)



_SUSTAINABILITYSERVICE = _descriptor.ServiceDescriptor(
  name='SustainabilityService',
  full_name='systemathics.apis.services.sustainability.v1.SustainabilityService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=501,
  serialized_end=682,
  methods=[
  _descriptor.MethodDescriptor(
    name='Sustainability',
    full_name='systemathics.apis.services.sustainability.v1.SustainabilityService.Sustainability',
    index=0,
    containing_service=None,
    input_type=_SUSTAINABILITYREQUEST,
    output_type=_SUSTAINABILITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SUSTAINABILITYSERVICE)

DESCRIPTOR.services_by_name['SustainabilityService'] = _SUSTAINABILITYSERVICE

# @@protoc_insertion_point(module_scope)
